@@ -1,6 +1,7 @@
 package operatorclient
 
 import (
+	"context"
 	"fmt"
 
 	v1 "k8s.io/api/core/v1"
@@ -11,17 +12,17 @@ import (
 
 // CreateService creates the Service.
 func (c *Client) CreateService(ig *v1.Service) (*v1.Service, error) {
-	return c.CoreV1().Services(ig.GetNamespace()).Create(ig)
+	return c.CoreV1().Services(ig.GetNamespace()).Create(context.TODO(), ig, metav1.CreateOptions{})
 }
 
 // GetService returns the existing Service.
 func (c *Client) GetService(namespace, name string) (*v1.Service, error) {
-	return c.CoreV1().Services(namespace).Get(name, metav1.GetOptions{})
+	return c.CoreV1().Services(namespace).Get(context.TODO(), name, metav1.GetOptions{})
 }
 
 // DeleteService deletes the Service.
 func (c *Client) DeleteService(namespace, name string, options *metav1.DeleteOptions) error {
-	return c.CoreV1().Services(namespace).Delete(name, options)
+	return c.CoreV1().Services(namespace).Delete(context.TODO(), name, *options)
 }
 
 // UpdateService will update the given Service resource.
@@ -35,5 +36,5 @@ func (c *Client) UpdateService(service *v1.Service) (*v1.Service, error) {
 	if err != nil {
 		return nil, fmt.Errorf("error creating patch for Service: %v", err)
 	}
-	return c.CoreV1().Services(service.GetNamespace()).Patch(service.GetName(), types.StrategicMergePatchType, patchBytes)
+	return c.CoreV1().Services(service.GetNamespace()).Patch(context.TODO(), service.GetName(), types.StrategicMergePatchType, patchBytes, metav1.PatchOptions{})
 }
